---
title: <span class="badge object-type-scalar"></span> PicoFarad
---
# <span class="badge object-type-scalar"></span> PicoFarad

Energy: Picofarad (pF)

## Definition

```python
# Energy: Picofarad (pF)
PicoFarad: typing.Literal["pfarad"] = "pfarad"
```
